@@ -1,10 +1,8 @@
 import Acquisition
 
-from Products.ATContentTypes import criteria
 from Products.ATContentTypes.criteria import sort
 
 from collective.formcriteria import interfaces
-from collective.formcriteria import topic
 from collective.formcriteria.criteria import common
 
 class ATSortCriterion(
@@ -25,9 +23,6 @@ class ATSortCriterion(
             return super(ATSortCriterion, self).getCriteriaItems()
         return ()
     
-indices = criteria._criterionRegistry.indicesByCriterion(
-    sort.ATSortCriterion.meta_type)
-criteria.unregisterCriterion(sort.ATSortCriterion)
-criteria.registerCriterion(
-    ATSortCriterion,
-    indices + tuple(topic.fake_sort_indices.keys()))
+
+common.replaceCriterionRegistration(sort.ATSortCriterion,
+                                    ATSortCriterion)
